@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 1.36 2005/05/29 09:48:46 fredo Exp $
+#   $Id: Content.pm,v 2.1 2006/06/19 19:25:44 areibens Exp $
 #
 #=======================================================================
 
@@ -43,11 +43,11 @@ BEGIN {
     use PDF::API2::Matrix;
     use Math::Trig;
     use Encode;
-    use Compress::Zlib;
+    use Compress::Zlib qw[];
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
     
-    ( $VERSION ) = '$Revision: 1.36 $' =~ /Revision: (\S+)\s/; # $Date: 2005/05/29 09:48:46 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2006/06/19 19:25:44 $
 
 }
 
@@ -1818,14 +1818,14 @@ sub text
         $self->matrix_update($wd,0);
     }
     my $ulxy1=[$self->textpos2];
-    if($self->{' font'}->isvirtual)
-    {
+    #if($self->{' font'}->isvirtual)
+    #{
         $self->add($self->{' font'}->text($text,$self->{' fontsize'}));
-    } 
-    else 
-    {
-        $self->add($self->{' font'}->text($text),'Tj');
-    }
+    #} 
+    #else 
+    #{
+    #    $self->add($self->{' font'}->text($text),'Tj');
+    #}
     $wd=$self->advancewidth($text);
     $self->matrix_update($wd,0);
 
@@ -2044,7 +2044,8 @@ sub textend {
 
 =item $width = $txt->textlabel $x, $y, $font, $size, $text, %options
 
-Applys text with options, but without teststart/end and optionally returns the width of the given text.
+Applys text with options, but without teststart/end 
+and optionally returns the width of the given text.
 
 B<Example:> 
 
@@ -2053,12 +2054,19 @@ B<Example:>
         -rotate => -30,
         -color => '#FF0000',
         -hspace => 120,
-        -center => 1,
+        -align => 'center',
+    );
+    $t->textlabel(500,500,$myfont,20,'Page Header',
+        -rotate => 30,
+        -color => '#0000FF',
+        -hspace => 80,
+        -align => 'right',
     );
     
 =cut
 
-sub textlabel {
+sub textlabel 
+{
     my ($self,$x,$y,$font,$size,$text,%opts,$wht) = @_;
     my %trans_opts=( -translate => [$x,$y] );
     my %text_state=();
@@ -2084,11 +2092,16 @@ sub textlabel {
     $self->wordspace($opts{-wordspace})     if($opts{-wordspace});
     $self->render($opts{-render})           if($opts{-render});
 
-    if($opts{-right} || $opts{-align}=~/^r/i) {
+    if($opts{-right} || $opts{-align}=~/^r/i) 
+    {
         $wht = $self->text_right($text,%opts);
-    } elsif($opts{-center} || $opts{-align}=~/^c/i) {
+    } 
+    elsif($opts{-center} || $opts{-align}=~/^c/i) 
+    {
         $wht = $self->text_center($text,%opts);
-    } else {
+    } 
+    else 
+    {
         $wht = $self->text($text,%opts);
     }
     
@@ -2150,6 +2163,30 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 2.1  2006/06/19 19:25:44  areibens
+    fixed compress vs. Compress::ZLib subs
+
+    Revision 2.0  2005/11/16 02:16:00  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:24  areibens
+    genesis
+
+    Revision 1.40  2005/10/19 19:04:43  fredo
+    added extended typographic text handling call
+
+    Revision 1.39  2005/10/01 22:10:57  fredo
+    added more docs for textlabel
+
+    Revision 1.38  2005/06/17 19:43:46  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.37  2005/06/17 18:53:04  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
     Revision 1.36  2005/05/29 09:48:46  fredo
     added conditional textstate2 method
 
