@@ -27,12 +27,13 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CIDFont.pm,v 1.12 2005/03/14 22:01:06 fredo Exp $
+#   $Id: CIDFont.pm,v 2.1 2006/06/19 19:22:07 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont;
 
-BEGIN {
+BEGIN 
+{
 
     use utf8;
     use Encode qw(:all);
@@ -48,9 +49,9 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::BaseFont );
 
-    ( $VERSION ) = '$Revision: 1.12 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:06 $
-
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2006/06/19 19:22:07 $
 }
+
 no warnings qw[ deprecated recursion uninitialized ];
 
 =item $font = PDF::API2::Resource::CIDFont->new $pdf, $name
@@ -59,7 +60,8 @@ Returns a cid-font object. base class form all CID based fonts.
 
 =cut
 
-sub new {
+sub new 
+{
     my ($class,$pdf,$name,@opts) = @_;
     my %opts=();
     %opts=@opts if((scalar @opts)%2 == 0);
@@ -95,7 +97,8 @@ it needs an PDF::API2-object rather than a Text::PDF::File-object.
 
 =cut
 
-sub new_api {
+sub new_api 
+{
     my ($class,$api,@opts)=@_;
 
     my $obj=$class->new($api->{pdf},@opts);
@@ -113,16 +116,22 @@ sub cidByUni { return( $_[0]->data->{u2g}->{$_[1]} ); }
 
 sub cidByEnc { return( $_[0]->data->{e2g}->[$_[1]] ); }
 
-sub wxByCId {
+sub wxByCId 
+{
     my $self=shift @_;
     my $g=shift @_;
     my $w;
 
-    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g]) {
+    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g]) 
+    {
         $w = int($self->data->{wx}->[$g]);
-    } elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g}) {
+    } 
+    elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g}) 
+    {
         $w = int($self->data->{wx}->{$g});
-    } else {
+    } 
+    else 
+    {
         $w = $self->missingwidth;
     }
 
@@ -132,15 +141,28 @@ sub wxByCId {
 sub wxByUni { return( $_[0]->wxByCId($_[0]->data->{u2g}->{$_[1]}) ); }
 sub wxByEnc { return( $_[0]->wxByCId($_[0]->data->{e2g}->[$_[1]]) ); }
 
-sub width {
+sub width 
+{
     my ($self,$text)=@_;
     return($self->width_cid($self->cidsByStr($text)));
 }
-sub width_cid {
+
+sub width_cid 
+{
     my ($self,$text)=@_;
     my $width=0;
-    foreach my $n (unpack('n*',$text)) {
+    my $lastglyph=0;
+    foreach my $n (unpack('n*',$text)) 
+    {
         $width+=$self->wxByCId($n);
+        if($self->{-dokern} && $self->haveKernPairs())
+        {
+            if($self->kernPairCid($lastglyph, $n))
+            {
+                $width-=$self->kernPairCid($lastglyph, $n);
+            }
+        }
+        $lastglyph=$n;                    
     }
     $width/=1000;
     return($width);
@@ -152,7 +174,8 @@ Returns the cid-string from string based on the fonts encoding map.
 
 =cut
 
-sub _cidsByStr {
+sub _cidsByStr 
+{
     my ($self,$s)=@_;
     $s=pack('n*',map { $self->cidByEnc($_) } unpack('C*',$s));
     return($s);
@@ -204,11 +227,22 @@ sub textByStr
     return($self->text_cid($self->cidsByStr($text)));
 }
 
+sub textByStrKern 
+{
+    my ($self,$text,$size)=@_;
+    return($self->text_cid_kern($self->cidsByStr($text),$size));
+}
+
 sub text 
 { 
     my ($self,$text,$size)=@_;
     my $newtext=$self->textByStr($text);
-    if(defined $size)
+    if(defined $size && $self->{-dokern})
+    {
+        $newtext=$self->textByStrKern($text,$size);
+        return($newtext);
+    }
+    elsif(defined $size)
     {
         return("$newtext Tj");
     }
@@ -223,7 +257,8 @@ sub text_cid
     my ($self,$text,$size)=@_;
     if(UNIVERSAL::can($self,'fontfile'))
     {
-        foreach my $g (unpack('n*',$text)) {
+        foreach my $g (unpack('n*',$text)) 
+        {
             $self->fontfile->subsetByCId($g);
         }
     }
@@ -238,7 +273,62 @@ sub text_cid
     }
 }
 
-sub encodeByName {
+sub text_cid_kern 
+{
+    my ($self,$text,$size)=@_;
+    if(UNIVERSAL::can($self,'fontfile'))
+    {
+        foreach my $g (unpack('n*',$text)) 
+        {
+            $self->fontfile->subsetByCId($g);
+        }
+    }
+    if(defined $size && $self->{-dokern} && $self->haveKernPairs())
+    {
+            my $newtext=' ';
+            my $lastglyph=0;
+            my $tBefore=0;
+            foreach my $n (unpack('n*',$text)) 
+            {
+                if($self->kernPairCid($lastglyph, $n))
+                {
+                    $newtext.='> ' if($tBefore);
+                    $newtext.=sprintf('%i ',$self->kernPairCid($lastglyph, $n));
+                    $tBefore=0;
+                }
+                $lastglyph=$n;
+                my $t=sprintf('%04X',$n);
+                $newtext.='<' if(!$tBefore);
+                $newtext.=$t;
+                $tBefore=1;
+            }
+            $newtext.='> ' if($tBefore);
+            return("[ $newtext ] TJ");
+    }
+    elsif(defined $size)
+    {
+        my $newtext=unpack('H*',$text);
+        return("<$newtext> Tj");
+    }
+    else
+    {
+        my $newtext=unpack('H*',$text);
+        return("<$newtext>");
+    }
+}
+
+sub kernPairCid 
+{
+    return(0);
+}
+
+sub haveKernPairs 
+{
+    return(0);
+}
+
+sub encodeByName 
+{
     my ($self,$enc) = @_;
     return if($self->issymbol);
 
@@ -247,29 +337,36 @@ sub encodeByName {
     $self->data->{e2g}=[ map { $self->data->{u2g}->{$_} || 0 } @{$self->data->{e2u}} ];
 
     $self->data->{u2e}={};
-    foreach my $n (reverse 0..255) {
+    foreach my $n (reverse 0..255) 
+    {
         $self->data->{u2e}->{$self->data->{e2u}->[$n]}=$n unless(defined $self->data->{u2e}->{$self->data->{e2u}->[$n]});
     }
 
     return($self);
 }
 
-sub subsetByCId {
-    return(1);
-}
-sub subvec {
+sub subsetByCId 
+{
     return(1);
 }
 
-sub glyphNum { 
+sub subvec 
+{
+    return(1);
+}
+
+sub glyphNum 
+{ 
     my $self=shift @_;
-    if(defined $self->data->{glyphs}) {
+    if(defined $self->data->{glyphs}) 
+    {
         return ( $self->data->{glyphs} ); 
     }
     return ( scalar @{$self->data->{wx}} ); 
 }
 
-sub outobjdeep {
+sub outobjdeep 
+{
     my ($self, $fh, $pdf, %opts) = @_;
 
     return $self->SUPER::outobjdeep($fh, $pdf) if defined $opts{'passthru'};
@@ -289,6 +386,27 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CIDFont.pm,v $
+    Revision 2.1  2006/06/19 19:22:07  areibens
+    removed dup sub
+
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
+    Revision 1.15  2005/10/20 21:05:05  fredo
+    added handling of optional kerning
+
+    Revision 1.14  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.13  2005/06/17 18:53:34  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
     Revision 1.12  2005/03/14 22:01:06  fredo
     upd 2005
 
